@@ -30,11 +30,11 @@ VSGDR::TestScriptGen - Unit test script support package for SSDT unit tests, Ded
 
 =head1 VERSION
 
-Version 0.13
+Version 0.15
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.15';
 
 
 sub databaseName {
@@ -227,7 +227,7 @@ sub generateScripts {
     my $database        = databaseName($dbh);
 
     no warnings;
-    my $userName        = $OSNAME eq 'MSWin32' ? Win32::LoginName : @{[getpwuid( $< )]}->[6]; $userName =~ s/,.*//;
+    my $userName        = $OSNAME eq 'MSWin32' ? Win32::LoginName : ${[getpwuid( $< )]}->[6]; $userName =~ s/,.*//;
     use warnings;
     my $date            = strftime "%d/%m/%Y", localtime;
 #warn Dumper $userName ;    
@@ -379,7 +379,7 @@ begin catch
 end catch
 
 
-if \@\@trancount > 0
+if \@\@trancount > 0 or xact_state() = -1
     rollback
 
 
@@ -460,7 +460,7 @@ begin catch
 end catch
 
 
-if \@\@trancount > 0
+if \@\@trancount > 0 or xact_state() = -1
     rollback
 
 
@@ -556,7 +556,7 @@ begin catch
 end catch
 
 
-if \@\@trancount > 0
+if \@\@trancount > 0 or xact_state() = -1
     rollback
 
 
